*******************
LTS Backport Policy
*******************

Starting with astropy v6.0.0, there will be no more designated Long-Term Stable
(LTS) releases of astropy - see `APE 21
<https://github.com/astropy/astropy-APEs/blob/main/APE21.rst>`_ for more details.
